#
# spec file for package ghc-cryptonite
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name cryptonite
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.21
Release:        3.1
Summary:        Cryptography Primitives sink
License:        BSD-3-Clause
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-memory-devel
BuildRequires:  ghc-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-byteable-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-kat-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
A repository of cryptographic primitives.

* Symmetric ciphers: AES, DES, 3DES, Blowfish, Camellia, RC4, Salsa, XSalsa,
ChaCha.

* Hash: SHA1, SHA2, SHA3, MD2, MD4, MD5, Keccak, Skein, Ripemd, Tiger,
Whirlpool, Blake2

* MAC: HMAC, Poly1305

* Asymmetric crypto: DSA, RSA, DH, ECDH, ECDSA, ECC, Curve25519, Ed25519, Ed448

* Key Derivation Function: PBKDF2, Scrypt, HKDF

* Cryptographic Random generation: System Entropy, Deterministic Random
Generator

* Data related: Anti-Forensic Information Splitter (AFIS)

If anything cryptographic related is missing from here, submit a pull request
to have it added. This package strive to be a cryptographic kitchen sink that
provides cryptography for everyone.

Evaluate the security related to your requirements before using.

Read "Crypto.Tutorial" for a quick start guide.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%define cabal_configure_options -f-support_aesni -f-support_rdrand -f-support_blake2_sse
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md

%changelog
* Wed Jan 18 2017 psimons@suse.com
- Update to version 0.21 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.19 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.15 revision 0 with cabal2obs.
* Sun Apr 10 2016 mimi.vx@gmail.com
- update to 0.14
  * Fix serialization of DH and ECDH
  * Reduce size of SHA3 context instead of allocating all-size fit memory. save up to
    72 bytes of memory per context for SHA3-512.
  * Add a Seed capability to the main DRG, to be able to debug/reproduce randomized
    program where you would want to disable the randomness.
  * Add support for Cipher-based Message Authentication Code (CMAC) (Kei Hibino)
  * CHANGE Change the SharedKey for Crypto.PubKey.DH and Crypto.PubKey.ECC.DH, from
    an Integer newtype to a ScrubbedBytes newtype. Prevent mistake where the bytes
    representation is generated without the right padding (when needed).
  * CHANGE Keep The field size in bits, in the Params in Crypto.PubKey.DH, moving
    from 2 elements to 3 elements in the structure.
* Mon Feb 22 2016 mimi.vx@gmail.com
- update to 0.13
  * SECURITY Fix buffer overflow issue in SHA384, copying 16 extra bytes from
    the SHA512 context to the destination memory pointer leading to memory
    corruption, segfault
  * Fix compilation issue with Ed448 on 32 bits machine.
* Sun Feb 14 2016 mimi.vx@gmail.com
- update to 0.11
  * Truncate hashing correctly for DSA
  * Add support for HKDF (RFC 5869)
  * Add support for Ed448
  * Extends support for Blake2s to 224 bits version.
  * Compilation fix with AESNI and ghci compiling C source in a weird order.
  * Fix example compilation, typo, and warning
* Fri Dec 25 2015 mimi.vx@gmail.com
- update to 0.10
- drop blake2-fix.patch
  * Add reference implementation of blake2 for non-SSE2 platfom
  * Add support_blake2_sse flag
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.9
  * Quiet down unused module imports
  * Move Curve25519 over to Crypto.Error instead of using Either String.
  * Add documentation for ChaChaPoly1305
  * Add missing documentation for various modules
  * Add a way to create Poly1305 Auth tag.
  * Added support for the BLAKE2 family of hash algorithms
  * Fix endianness of incrementNonce function for ChaChaPoly1305
  * Add support for ChaChaPoly1305 Nonce Increment
  * Add PKCS5 / PKCS7 padding and unpadding methods
  * Fix ChaChaPoly1305 Decryption
  * Add support for BCrypt
- add blake2-fix.patch and disabled build of sse4.1 optimized blake2
* Thu Aug  6 2015 mimi.vx@gmail.com
- initial commit
